@@ -2145,7 +2145,8 @@ module.exports = {
 		"32.2.8",
 		"32.3.0",
 		"32.3.1",
-		"32.3.2"
+		"32.3.2",
+		"32.3.3"
 	],
 	"129.0.6668.0": [
 		"33.0.0-alpha.1"
@@ -2198,7 +2199,16 @@ module.exports = {
 		"33.3.2",
 		"33.4.0",
 		"33.4.1",
-		"33.4.2"
+		"33.4.2",
+		"33.4.3",
+		"33.4.4",
+		"33.4.5",
+		"33.4.6",
+		"33.4.7",
+		"33.4.8",
+		"33.4.9",
+		"33.4.10",
+		"33.4.11"
 	],
 	"131.0.6776.0": [
 		"34.0.0-alpha.1"
@@ -2260,7 +2270,22 @@ module.exports = {
 		"34.2.0"
 	],
 	"132.0.6834.210": [
-		"34.3.0"
+		"34.3.0",
+		"34.3.1",
+		"34.3.2",
+		"34.3.3",
+		"34.3.4",
+		"34.4.0",
+		"34.4.1",
+		"34.5.0",
+		"34.5.1",
+		"34.5.2",
+		"34.5.3",
+		"34.5.4",
+		"34.5.5",
+		"34.5.6",
+		"34.5.7",
+		"34.5.8"
 	],
 	"133.0.6920.0": [
 		"35.0.0-alpha.1",
@@ -2290,5 +2315,108 @@ module.exports = {
 		"35.0.0-beta.10",
 		"35.0.0-beta.11",
 		"35.0.0-beta.12"
+	],
+	"134.0.6998.44": [
+		"35.0.0-beta.13",
+		"35.0.0",
+		"35.0.1"
+	],
+	"134.0.6998.88": [
+		"35.0.2",
+		"35.0.3"
+	],
+	"134.0.6998.165": [
+		"35.1.0",
+		"35.1.1"
+	],
+	"134.0.6998.178": [
+		"35.1.2"
+	],
+	"134.0.6998.179": [
+		"35.1.3",
+		"35.1.4",
+		"35.1.5"
+	],
+	"134.0.6998.205": [
+		"35.2.0",
+		"35.2.1",
+		"35.2.2",
+		"35.3.0",
+		"35.4.0",
+		"35.5.0",
+		"35.5.1"
+	],
+	"135.0.7049.5": [
+		"36.0.0-alpha.1"
+	],
+	"136.0.7062.0": [
+		"36.0.0-alpha.2",
+		"36.0.0-alpha.3",
+		"36.0.0-alpha.4"
+	],
+	"136.0.7067.0": [
+		"36.0.0-alpha.5",
+		"36.0.0-alpha.6",
+		"36.0.0-beta.1",
+		"36.0.0-beta.2",
+		"36.0.0-beta.3",
+		"36.0.0-beta.4"
+	],
+	"136.0.7103.17": [
+		"36.0.0-beta.5"
+	],
+	"136.0.7103.25": [
+		"36.0.0-beta.6",
+		"36.0.0-beta.7"
+	],
+	"136.0.7103.33": [
+		"36.0.0-beta.8",
+		"36.0.0-beta.9"
+	],
+	"136.0.7103.48": [
+		"36.0.0",
+		"36.0.1"
+	],
+	"136.0.7103.49": [
+		"36.1.0",
+		"36.2.0"
+	],
+	"136.0.7103.93": [
+		"36.2.1"
+	],
+	"136.0.7103.113": [
+		"36.3.0",
+		"36.3.1"
+	],
+	"136.0.7103.115": [
+		"36.3.2"
+	],
+	"136.0.7103.149": [
+		"36.4.0"
+	],
+	"137.0.7151.0": [
+		"37.0.0-alpha.1",
+		"37.0.0-alpha.2"
+	],
+	"138.0.7156.0": [
+		"37.0.0-alpha.3"
+	],
+	"138.0.7165.0": [
+		"37.0.0-alpha.4"
+	],
+	"138.0.7177.0": [
+		"37.0.0-alpha.5"
+	],
+	"138.0.7178.0": [
+		"37.0.0-alpha.6",
+		"37.0.0-alpha.7",
+		"37.0.0-beta.1",
+		"37.0.0-beta.2"
+	],
+	"138.0.7190.0": [
+		"37.0.0-beta.3"
+	],
+	"138.0.7204.15": [
+		"37.0.0-beta.4"
 	]
 };
\ No newline at end of file
