@@ -1405,6 +1405,7 @@ module.exports = {
 	"32.3.0": "128.0.6613.186",
 	"32.3.1": "128.0.6613.186",
 	"32.3.2": "128.0.6613.186",
+	"32.3.3": "128.0.6613.186",
 	"33.0.0-alpha.1": "129.0.6668.0",
 	"33.0.0-alpha.2": "130.0.6672.0",
 	"33.0.0-alpha.3": "130.0.6672.0",
@@ -1434,6 +1435,15 @@ module.exports = {
 	"33.4.0": "130.0.6723.191",
 	"33.4.1": "130.0.6723.191",
 	"33.4.2": "130.0.6723.191",
+	"33.4.3": "130.0.6723.191",
+	"33.4.4": "130.0.6723.191",
+	"33.4.5": "130.0.6723.191",
+	"33.4.6": "130.0.6723.191",
+	"33.4.7": "130.0.6723.191",
+	"33.4.8": "130.0.6723.191",
+	"33.4.9": "130.0.6723.191",
+	"33.4.10": "130.0.6723.191",
+	"33.4.11": "130.0.6723.191",
 	"34.0.0-alpha.1": "131.0.6776.0",
 	"34.0.0-alpha.2": "132.0.6779.0",
 	"34.0.0-alpha.3": "132.0.6789.1",
@@ -1466,6 +1476,21 @@ module.exports = {
 	"34.1.1": "132.0.6834.194",
 	"34.2.0": "132.0.6834.196",
 	"34.3.0": "132.0.6834.210",
+	"34.3.1": "132.0.6834.210",
+	"34.3.2": "132.0.6834.210",
+	"34.3.3": "132.0.6834.210",
+	"34.3.4": "132.0.6834.210",
+	"34.4.0": "132.0.6834.210",
+	"34.4.1": "132.0.6834.210",
+	"34.5.0": "132.0.6834.210",
+	"34.5.1": "132.0.6834.210",
+	"34.5.2": "132.0.6834.210",
+	"34.5.3": "132.0.6834.210",
+	"34.5.4": "132.0.6834.210",
+	"34.5.5": "132.0.6834.210",
+	"34.5.6": "132.0.6834.210",
+	"34.5.7": "132.0.6834.210",
+	"34.5.8": "132.0.6834.210",
 	"35.0.0-alpha.1": "133.0.6920.0",
 	"35.0.0-alpha.2": "133.0.6920.0",
 	"35.0.0-alpha.3": "133.0.6920.0",
@@ -1482,5 +1507,58 @@ module.exports = {
 	"35.0.0-beta.9": "134.0.6998.10",
 	"35.0.0-beta.10": "134.0.6998.23",
 	"35.0.0-beta.11": "134.0.6998.23",
-	"35.0.0-beta.12": "134.0.6998.23"
+	"35.0.0-beta.12": "134.0.6998.23",
+	"35.0.0-beta.13": "134.0.6998.44",
+	"35.0.0": "134.0.6998.44",
+	"35.0.1": "134.0.6998.44",
+	"35.0.2": "134.0.6998.88",
+	"35.0.3": "134.0.6998.88",
+	"35.1.0": "134.0.6998.165",
+	"35.1.1": "134.0.6998.165",
+	"35.1.2": "134.0.6998.178",
+	"35.1.3": "134.0.6998.179",
+	"35.1.4": "134.0.6998.179",
+	"35.1.5": "134.0.6998.179",
+	"35.2.0": "134.0.6998.205",
+	"35.2.1": "134.0.6998.205",
+	"35.2.2": "134.0.6998.205",
+	"35.3.0": "134.0.6998.205",
+	"35.4.0": "134.0.6998.205",
+	"35.5.0": "134.0.6998.205",
+	"35.5.1": "134.0.6998.205",
+	"36.0.0-alpha.1": "135.0.7049.5",
+	"36.0.0-alpha.2": "136.0.7062.0",
+	"36.0.0-alpha.3": "136.0.7062.0",
+	"36.0.0-alpha.4": "136.0.7062.0",
+	"36.0.0-alpha.5": "136.0.7067.0",
+	"36.0.0-alpha.6": "136.0.7067.0",
+	"36.0.0-beta.1": "136.0.7067.0",
+	"36.0.0-beta.2": "136.0.7067.0",
+	"36.0.0-beta.3": "136.0.7067.0",
+	"36.0.0-beta.4": "136.0.7067.0",
+	"36.0.0-beta.5": "136.0.7103.17",
+	"36.0.0-beta.6": "136.0.7103.25",
+	"36.0.0-beta.7": "136.0.7103.25",
+	"36.0.0-beta.8": "136.0.7103.33",
+	"36.0.0-beta.9": "136.0.7103.33",
+	"36.0.0": "136.0.7103.48",
+	"36.0.1": "136.0.7103.48",
+	"36.1.0": "136.0.7103.49",
+	"36.2.0": "136.0.7103.49",
+	"36.2.1": "136.0.7103.93",
+	"36.3.0": "136.0.7103.113",
+	"36.3.1": "136.0.7103.113",
+	"36.3.2": "136.0.7103.115",
+	"36.4.0": "136.0.7103.149",
+	"37.0.0-alpha.1": "137.0.7151.0",
+	"37.0.0-alpha.2": "137.0.7151.0",
+	"37.0.0-alpha.3": "138.0.7156.0",
+	"37.0.0-alpha.4": "138.0.7165.0",
+	"37.0.0-alpha.5": "138.0.7177.0",
+	"37.0.0-alpha.6": "138.0.7178.0",
+	"37.0.0-alpha.7": "138.0.7178.0",
+	"37.0.0-beta.1": "138.0.7178.0",
+	"37.0.0-beta.2": "138.0.7178.0",
+	"37.0.0-beta.3": "138.0.7190.0",
+	"37.0.0-beta.4": "138.0.7204.15"
 };
\ No newline at end of file
